<?php 
	function sarkpress_build_options_page() { 
?>
		<div id="theme-options-wrap" class="widefat">
			<div class="icon32" id="icon-tools"> <br /> </div>
			<h2>Sark Press Options</h2>
			<p>Customize your website through various options.</p>
			<form method="post" action="options.php" enctype="multipart/form-data">
				<?php settings_fields('sarkpress_theme_options'); ?>
				<?php do_settings_sections(__FILE__); ?>
				<p class="submit">
					<input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" />
				</p>
			</form>
		</div>
<?php
	}
	
	function sarkpress_options_init() {}	
	add_action( 'after_setup_theme', 'sarkpress_options_init' );
	
	function sarkpress_register_and_build_fields() {		
		/* Register Settings */
		register_setting('sarkpress_theme_options', 'sarkpress_theme_options', 'sarkpress_validate_setting');
		/* Register Settings Groups */
		add_settings_section('sarkpress_general_settings', 'General Settings', 'sarkpress_section_general', __FILE__);
		add_settings_section('sarkpress_contact_settings', 'Contact Settings', 'sarkpress_section_contact', __FILE__);
		add_settings_section('sarkpress_social_settings', 'Social Settings', 'sarkpress_section_social', __FILE__);
		/* Fields for General Section */		
		add_settings_field('logo', 'Logo', 'sarkpress_logo_setting', __FILE__, 'sarkpress_general_settings');
		add_settings_field('favicon', 'Favicon', 'sarkpress_favicon_setting', __FILE__, 'sarkpress_general_settings');
		add_settings_field('footer', 'Footer Text', 'sarkpress_footer_setting', __FILE__, 'sarkpress_general_settings');
		/* Fields for Contact Section */		
		add_settings_field('phonenumber', 'Phone Number', 'sarkpress_phonenumber_setting', __FILE__, 'sarkpress_contact_settings');
		add_settings_field('email', 'Email', 'sarkpress_email_setting', __FILE__, 'sarkpress_contact_settings');
		/* Fields for Social Section */
		add_settings_field('facebook', 'Facebook', 'sarkpress_facebook_setting', __FILE__, 'sarkpress_social_settings');
		add_settings_field('twitter', 'Twitter', 'sarkpress_twitter_setting', __FILE__, 'sarkpress_social_settings');
		add_settings_field('linkedin', 'LinkedIn', 'sarkpress_linkedin_setting', __FILE__, 'sarkpress_social_settings');
		add_settings_field('googleplus', 'Google+', 'sarkpress_googleplus_setting', __FILE__, 'sarkpress_social_settings');
		add_settings_field('youtube', 'Youtube', 'sarkpress_youtube_setting', __FILE__, 'sarkpress_social_settings');		
	}
	add_action('admin_init', 'sarkpress_register_and_build_fields');
	
	/* Callback for Validation */	
	function sarkpress_validate_setting( $theme_options ) { 		
		foreach ( $theme_options as $option => $value ){
			$theme_options[ $option ] = apply_filters( 'sarkpress_option_' . $option, $value );
		}
		return $theme_options;
	}
	
	/* EMail validation */
	function sarkpress_validate_email( $value ) {
		if( !is_email( $value ) ) { $value = ''; }
		return $value;
	}
	add_filter( 'sarkpress_option_email', 'sarkpress_validate_email' );
	
	/* URL validation */
	function sarkpress_validate_url( $value ) {
		return esc_url_raw( $value );
	}
	add_filter( 'sarkpress_option_logo', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_favicon', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_facebook', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_twitter', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_linkedin', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_googleplus', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_youtube', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_url', 'sarkpress_validate_url' );
	add_filter( 'sarkpress_option_image', 'sarkpress_validate_url' );
	
	/* String sanitization */
	function sarkpress_validate_text( $value ) {
		return wp_filter_nohtml_kses( $value );
	}
	add_filter( 'sarkpress_option_footer', 'sarkpress_validate_text' );

	/* Callback functions for Setting Sections */
	function sarkpress_section_general() {
		echo '<p>Setup Logo, Favicon & Footer text for your website.</p>';
	}
	function sarkpress_section_contact() {
		echo '<p>Setup contact details for your website.</p>';
	}
	function sarkpress_section_social() {
		echo '<p>Setup social connection details for your website</p>';
	}
	
	/* Contructing Fields for General Section */
	function sarkpress_logo_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[logo]' id='sarkpress_theme_options_logo' type='text' value='{$options['logo']}' /> <input id='sarkpress_theme_options_logo_btn' type='button' value='Upload Logo' />";
	}
	function sarkpress_favicon_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[favicon]' id='sarkpress_theme_options_favicon' type='text' value='{$options['favicon']}' /> <input id='sarkpress_theme_options_favicon_btn' type='button' value='Upload Favicon' />";
	}
	function sarkpress_footer_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[footer]' type='text' value='{$options['footer']}' />";
	}
	/* Constructing Fields for Contact Section */
	function sarkpress_phonenumber_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[phonenumber]' type='text' value='{$options['phonenumber']}' />";
	}
	function sarkpress_email_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[email]' type='text' value='{$options['email']}' />";
	}	
	/* Constructing Fields for Social Section */
	function sarkpress_facebook_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[facebook]' type='text' value='{$options['facebook']}' />";
	}
	function sarkpress_twitter_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[twitter]' type='text' value='{$options['twitter']}' />";
	}
	function sarkpress_linkedin_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[linkedin]' type='text' value='{$options['linkedin']}' />";
	}
	function sarkpress_googleplus_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[googleplus]' type='text' value='{$options['googleplus']}' />";
	}
	function sarkpress_youtube_setting() {
		$options = get_option('sarkpress_theme_options');  echo "<input name='sarkpress_theme_options[youtube]' type='text' value='{$options['youtube']}' />";
	}
	
	add_action('admin_menu', 'sarkpress_theme_options_page');
	function sarkpress_theme_options_page() {  add_theme_page( 'Sark Press Options', 'Sark Press Options', 'edit_theme_options', 'sarkpress_options_page', 'sarkpress_build_options_page');}
	/* Enqueue scripts & styles for option page */
	function sarkpress_options_enqueue_scripts() {		
		if ( 'appearance_page_sarkpress_options_page' == get_current_screen() -> id ) {
			wp_enqueue_style('thickbox');
			wp_enqueue_style( 'sarkpress-options', get_template_directory_uri() . '/inc/sarkpress-options.css', array( 'thickbox' ), '20121010' );
			wp_enqueue_script('thickbox');			
			wp_enqueue_script('media-upload');
			wp_enqueue_script('sarkpress-upload', get_template_directory_uri() .'/inc/sarkpress-upload.js', array('jquery','media-upload','thickbox'));	
		}	
	}
	add_action('admin_enqueue_scripts', 'sarkpress_options_enqueue_scripts');
?>